#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pureMD5
version:              2.1.4
visibility:           public
id:                   pureMD5-2.1.4-Jo1qVdZMEIjJtW87EOHzYT
key:                  pureMD5-2.1.4-Jo1qVdZMEIjJtW87EOHzYT
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.

description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.

category:             Data, Cryptography
abi:                  d150ff6d16056f9609c7ee65e9db2e11
exposed:              True
exposed-modules:      Data.Digest.Pure.MD5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pureMD5-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pureMD5-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pureMD5-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-puremd5
hs-libraries:         HSpureMD5-2.1.4-Jo1qVdZMEIjJtW87EOHzYT
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    crypto-api-0.13.3-5Lfgsrp27JqCvocn2Yi2a9
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j

haddock-interfaces:   /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html:         /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

